@@ -134,15 +134,19 @@ class PrefetchGenerator(Thread):
                 iterable = iterable[:]
                 random.shuffle(iterable)
             num_units = len(units)
+
             for idx, item in enumerate(iterable):
                 if self._is_running:
                     units[idx % num_units].put(item)
                 else:
-                    # stop이 호출된 경우
-                    # unit에 있는 queue를 비우고 데이터 할당을 중단
-                    while not units[idx % num_units].data.empty():
-                        units[idx % num_units].data.get()
                     break
+                
+            # stop이 호출된 경우
+            # unit에 있는 queue를 비우고 데이터 할당을 중단
+            if not self._is_running:
+                for unit_id, unit in units.items():
+                    while unit.data.empty():
+                        unit.data.get()
 
             # 데이터 할당이 끝났다는 것을 알려줌
             for unit in units.values():
